/**
 * @license lucide-react v0.503.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createLucideIcon from '../createLucideIcon.js';

const __iconNode = [["circle", { cx: "12", cy: "12", r: "6", key: "1vlfrh" }]];
const CircleSmall = createLucideIcon("circle-small", __iconNode);

export { __iconNode, CircleSmall as default };//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/7772f905dc6ba5632ae304533f286ac049f59543/node_modules/lucide-react/dist/esm/icons/circle-small.js.map
