"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseEnumDef = void 0;
function parseEnumDef(def) {
    return {
        type: 'string',
        enum: [...def.values],
    };
}
exports.parseEnumDef = parseEnumDef;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/7772f905dc6ba5632ae304533f286ac049f59543/node_modules/openai/_vendor/zod-to-json-schema/parsers/enum.js.map